# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django import template
from django.utils.safestring import mark_safe
from classytags.arguments import Argument
from classytags.core import Options
from cms.templatetags.cms_tags import RenderPlaceholder


register = template.Library()


class GetPlaceholderContent(RenderPlaceholder):
    """
    With this tag, you can retrieve a placeholder's content into a variable

    Exemple :
        {% get_placeholder_content news.newsbox_body as body %}
            {% if body %}
                {{ body|safe }}
                some extra html
            {% else %}
                fall back
            {% endif %}
        {% endget_placeholder_content %}
    """
    name = 'get_placeholder_content'
    options = Options(
        Argument('placeholder', resolve=True),
        Argument('width', default=None, required=False),
        'language',
        Argument('language', default=None, required=False),
        'as',
        Argument('varname', resolve=False),
        blocks=[
            ('endget_placeholder_content', 'nodelist'),
        ]
    )

    def get_value(self, context, nodelist, **kwargs):
        placeholder_output = None
        varname = kwargs.get('varname', None)
        if kwargs.get('placeholder',None):
            placeholder_output = super(GetPlaceholderContent, self).get_value(
                context, **kwargs)

        context.push()
        context[varname] = mark_safe(placeholder_output)
        output = nodelist.render(context)
        context.pop()
        return output


register.tag(GetPlaceholderContent)
